@@ -1441,7 +1441,7 @@ public class User {
      *
      */
     public String getImapServer() {
-        return imapServer;
+        return null == imapServer ? imapServerString : imapServer;
     }
 
     /**
@@ -2257,7 +2257,7 @@ public class User {
      *
      */
     public String getSmtpServer() {
-        return smtpServer;
+        return null == smtpServer ? smtpServerString : smtpServer;
     }
 
     /**
